@@ -1,24 +1,29 @@
 /*
- * Copyright (C) 2006 - 2011 The GNOME Foundation.
+ * Copyright (C) 2006 - 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 Leonardo Boshell <lb@kmc.com.co>
+ * Copyright (C) 2008 Armin Burgmeier <armin@openismus.com>
+ * Copyright (C) 2008 Phil Longstaff <plongstaff@rogers.com>
+ * Copyright (C) 2008 Przemysław Grzegorczyk <pgrzegorczyk@gmail.com>
+ * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
+ * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
- *      Daniel Espinosa <esodan@gmail.com>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -938,12 +943,15 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root, G
 		else if (!strcmp ((gchar*)node->name, "parameter")) {
 			GdaHolder *param = NULL;
 			xmlChar *gdatype;
+			GType gt;
 
 			/* find data type and create GdaHolder */
 			gdatype = xmlGetProp (node, BAD_CAST "gdatype");
+			gt = gdatype ? gda_g_type_from_string ((gchar*) gdatype) : G_TYPE_STRING;
+			if (gt == G_TYPE_INVALID)
+				gt = GDA_TYPE_NULL;
 			param = GDA_HOLDER (g_object_new (GDA_TYPE_HOLDER,
-							  "g-type", 
-							  gdatype ? gda_g_type_from_string ((gchar*) gdatype) : G_TYPE_STRING,
+							  "g-type", gt,
 							  NULL));
 			if (gdatype)
 				xmlFree (gdatype);
@@ -2080,8 +2088,8 @@ gda_server_operation_get_value_at (GdaServerOperation *op, const gchar *path_for
 /**
  * gda_server_operation_get_sql_identifier_at: (skip)
  * @op: a #GdaServerOperation object
- * @cnc: a #GdaConnection, or %NULL
- * @prov: a #GdaServerProvider, or %NULL
+ * @cnc: (allow-none): a #GdaConnection, or %NULL
+ * @prov: (allow-none): a #GdaServerProvider, or %NULL
  * @path_format: a complete path to a node (starting with "/")
  * @...: arguments to use with @path_format to make a complete path
  *
@@ -2119,8 +2127,8 @@ gda_server_operation_get_sql_identifier_at (GdaServerOperation *op, GdaConnectio
 /**
  * gda_server_operation_get_sql_identifier_at_path:
  * @op: a #GdaServerOperation object
- * @cnc: a #GdaConnection, or %NULL
- * @prov: a #GdaServerProvider, or %NULL
+ * @cnc: (allow-none): a #GdaConnection, or %NULL
+ * @prov: (allow-none): a #GdaServerProvider, or %NULL
  * @path: a complete path to a node (starting with "/")
  *
  * This method is similar to gda_server_operation_get_value_at(), but for SQL identifiers: a new string
@@ -2160,9 +2168,9 @@ gda_server_operation_get_sql_identifier_at_path (GdaServerOperation *op, GdaConn
 /**
  * gda_server_operation_set_value_at_path:
  * @op: a #GdaServerOperation object
- * @value: a string
- * @error: a place to store errors or %NULL
+ * @value: (allow-none): a string
  * @path: a complete path to a node (starting with "/")
+ * @error: a place to store errors or %NULL
  *
  * Set the value for the node at the path formed using @path_format and the ... ellipse (the rules are the same as
  * for g_strdup_printf()). 
@@ -2342,7 +2350,7 @@ gda_server_operation_set_value_at_path (GdaServerOperation *op, const gchar *val
 /**
  * gda_server_operation_set_value_at: (skip)
  * @op: a #GdaServerOperation object
- * @value: a string
+ * @value: (allow-none): a string
  * @error: a place to store errors or %NULL
  * @path_format: a complete path to a node (starting with "/")
  * @...: arguments to use with @path_format to make a complete path
@@ -2404,7 +2412,7 @@ gda_server_operation_set_value_at (GdaServerOperation *op, const gchar *value, G
 /**
  * gda_server_operation_is_valid:
  * @op: a #GdaServerOperation widget
- * @xml_file: an XML specification file (see gda_server_operation_new())
+ * @xml_file: (allow-none): an XML specification file (see gda_server_operation_new()) or %NULL
  * @error: a place to store an error, or %NULL
  *
  * Tells if all the required values in @op have been defined.
@@ -2477,7 +2485,7 @@ gda_server_operation_is_valid (GdaServerOperation *op, const gchar *xml_file, GE
 /**
  * gda_server_operation_prepare_create_database:
  * @provider: the database provider to use
- * @db_name: the name of the database to create, or %NULL
+ * @db_name: (allow-none): the name of the database to create, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Creates a new #GdaServerOperation object which contains the specifications required
@@ -2517,7 +2525,7 @@ gda_server_operation_prepare_create_database (const gchar *provider, const gchar
 
 /**
  * gda_server_operation_perform_create_database:
- * @provider: the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_create_database()
+ * @provider: (allow-none): the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_create_database()
  * @op: a #GdaServerOperation object obtained using gda_server_operation_prepare_create_database()
  * @error: a place to store en error, or %NULL
  *
@@ -2550,7 +2558,7 @@ gda_server_operation_perform_create_database (GdaServerOperation *op, const gcha
 /**
  * gda_server_operation_prepare_drop_database:
  * @provider: the database provider to use
- * @db_name: the name of the database to drop, or %NULL
+ * @db_name: (allow-none): the name of the database to drop, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Creates a new #GdaServerOperation object which contains the specifications required
@@ -2590,7 +2598,7 @@ gda_server_operation_prepare_drop_database (const gchar *provider, const gchar *
 
 /**
  * gda_server_operation_perform_drop_database:
- * @provider: the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_drop_database()
+ * @provider: (allow-none): the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_drop_database()
  * @op: a #GdaServerOperation object obtained using gda_server_operation_prepare_drop_database()
  * @error: a place to store en error, or %NULL
  *
