@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
@@ -75,8 +75,7 @@ enum
 	PROP_ID,
 	PROP_NAME,
 	PROP_DESCR,
-	PROP_HOLDERS,
-	PROP_VALIDATE_CHANGES
+	PROP_HOLDERS
 };
 
 /* signals */
@@ -104,7 +103,6 @@ struct _GdaSetPrivate
 	GHashTable      *holders_hash; /* key = GdaHoler ID, value = GdaHolder */
 	GArray          *holders_array;
 	gboolean         read_only;
-	gboolean         validate_changes;
 };
 
 static void 
@@ -132,29 +130,11 @@ gda_set_set_property (GObject *object,
 	case PROP_HOLDERS: {
 		/* add the holders */
 		GSList* holders;
-		for (holders = (GSList*) g_value_get_pointer (value); holders; holders = holders->next) 
+		for (holders = (GSList*) g_value_get_pointer(value); holders; holders = holders->next) 
 			gda_set_real_add_holder (set, GDA_HOLDER (holders->data));
 		compute_public_data (set);	
 		break;
 	}
-	case PROP_VALIDATE_CHANGES:
-		if (set->priv->validate_changes != g_value_get_boolean (value)) {
-			GSList *list;
-			set->priv->validate_changes = g_value_get_boolean (value);
-			for (list = set->holders; list; list = list->next) {
-				GdaHolder *holder = (GdaHolder*) list->data;
-				g_object_set ((GObject*) holder, "validate-changes",
-					      set->priv->validate_changes, NULL);
-				if (set->priv->validate_changes)
-					g_signal_connect ((GObject*) holder, "validate-change",
-							  G_CALLBACK (validate_change_holder_cb), set);
-				else
-					g_signal_handlers_disconnect_by_func ((GObject*) holder,
-									      G_CALLBACK (validate_change_holder_cb),
-									      set);
-			}
-		}
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -183,9 +163,6 @@ gda_set_get_property (GObject *object,
 	case PROP_DESCR:
 		g_value_set_string (value, set->priv->descr);
 		break;
-	case PROP_VALIDATE_CHANGES:
-		g_value_set_boolean (value, set->priv->validate_changes);
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -292,7 +269,7 @@ gda_set_class_init (GdaSetClass *class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GdaSetClass, validate_holder_change),
 			      validate_accumulator, NULL,
-			      _gda_marshal_ERROR__OBJECT_VALUE, GDA_TYPE_ERROR, 2,
+			      _gda_marshal_ERROR__OBJECT_VALUE, G_TYPE_ERROR, 2,
 			      GDA_TYPE_HOLDER, G_TYPE_VALUE);
 	/**
 	 * GdaSet::validate-set
@@ -310,7 +287,7 @@ gda_set_class_init (GdaSetClass *class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GdaSetClass, validate_set),
 			      validate_accumulator, NULL,
-			      _gda_marshal_ERROR__VOID, GDA_TYPE_ERROR, 0);
+			      _gda_marshal_ERROR__VOID, G_TYPE_ERROR, 0);
 	/**
 	 * GdaSet::holder-attr-changed
 	 * @set: the #GdaSet
@@ -404,18 +381,7 @@ gda_set_class_init (GdaSetClass *class)
 					 g_param_spec_pointer ("holders", "GSList of GdaHolders", 
 							       "GdaHolder objects the set should contain", (
 								G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY)));
-	/**
-	 * GdaSet:validate-changes:
-	 *
-	 * Defines if the "validate-set" signal gets emitted when
-	 * any holder in the data set changes. This property also affects the
-	 * GdaHolder:validate-changes property.
-	 *
-	 * Since: 5.2.0
-	 */
-	g_object_class_install_property (object_class, PROP_VALIDATE_CHANGES,
-					 g_param_spec_boolean ("validate-changes", NULL, "Defines if the validate-set signal is emitted", TRUE,
-							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+  
 	object_class->dispose = gda_set_dispose;
 	object_class->finalize = gda_set_finalize;
 }
@@ -431,13 +397,12 @@ gda_set_init (GdaSet *set)
 	set->priv->holders_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	set->priv->holders_array = NULL;
 	set->priv->read_only = FALSE;
-	set->priv->validate_changes = TRUE;
 }
 
 
 /**
  * gda_set_new:
- * @holders: (element-type Gda.Holder) (transfer none): a list of #GdaHolder objects
+ * @holders: (element-type GdaHolder) (transfer:none): a list of #GdaHolder objects
  *
  * Creates a new #GdaSet object, and populates it with the list given as argument.
  * The list can then be freed as it is copied. All the value holders in @holders are referenced counted
@@ -460,7 +425,7 @@ gda_set_new (GSList *holders)
 
 /**
  * gda_set_new_read_only:
- * @holders: (element-type Gda.Holder) (transfer none): a list of #GdaHolder objects
+ * @holders: (element-type GdaHolder) (transfer:none): a list of #GdaHolder objects
  *
  * Creates a new #GdaSet like gda_set_new(), but does not allow modifications to any of the #GdaHolder
  * object in @holders. This function is used for Libgda's database providers' implementation.
@@ -690,7 +655,7 @@ gda_set_set_holder_value (GdaSet *set, GError **error, const gchar *holder_id, .
 	else if (type == G_TYPE_GTYPE)
 		g_value_set_gtype (value, va_arg (ap, GType));	
 	else {
-		g_set_error (error, GDA_SET_ERROR, GDA_SET_IMPLEMENTATION_ERROR,
+		g_set_error (error, 0, 0,
 			     _("%s() does not handle values of type '%s'."),
 			     __FUNCTION__, g_type_name (type));
 		va_end (ap);
@@ -885,8 +850,7 @@ gda_set_new_from_spec_node (xmlNodePtr xml_spec, GError **error)
 				errors = gda_data_model_import_get_errors (GDA_DATA_MODEL_IMPORT (model));
 				if (errors) {
 					GError *err = (GError *) errors->data;
-					g_set_error (error, GDA_SET_ERROR, GDA_SET_XML_SPEC_ERROR,
-						     "%s", err->message);
+					g_set_error (error, 0, 0, "%s", err->message);
 					g_object_unref (model);
 					model = NULL;
 					allok = FALSE;
@@ -940,9 +904,12 @@ gda_set_new_from_spec_node (xmlNodePtr xml_spec, GError **error)
 			gdatype = xmlGetProp (cur, BAD_CAST "gdatype");
 
 			if (!holder) {
+				GType gt;
+				gt = gdatype ? gda_g_type_from_string ((gchar *) gdatype) : G_TYPE_STRING;
+				if (gt == G_TYPE_INVALID)
+					gt = GDA_TYPE_NULL;
 				holder = (GdaHolder*) (g_object_new (GDA_TYPE_HOLDER,
-								     "g-type", 
-								     gdatype ? gda_g_type_from_string ((gchar *) gdatype) : G_TYPE_STRING,
+								     "g-type", gt,
 								     NULL));
 				holders = g_slist_append (holders, holder);
 			}
@@ -1017,9 +984,8 @@ gda_set_remove_holder (GdaSet *set, GdaHolder *holder)
 	g_return_if_fail (set->priv);
 	g_return_if_fail (g_slist_find (set->holders, holder));
 
-	if (set->priv->validate_changes)
-		g_signal_handlers_disconnect_by_func (G_OBJECT (holder),
-						      G_CALLBACK (validate_change_holder_cb), set);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (holder),
+					      G_CALLBACK (validate_change_holder_cb), set);
 	if (! set->priv->read_only) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (holder),
 						      G_CALLBACK (changed_holder_cb), set);
@@ -1124,9 +1090,8 @@ gda_set_dispose (GObject *object)
 	/* free the holders list */
 	if (set->holders) {
 		for (list = set->holders; list; list = list->next) {
-			if (set->priv->validate_changes)
-				g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
-								      G_CALLBACK (validate_change_holder_cb), set);
+			g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
+							      G_CALLBACK (validate_change_holder_cb), set);
 			if (! set->priv->read_only) {
 				g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
 								      G_CALLBACK (changed_holder_cb), set);
@@ -1358,9 +1323,8 @@ gda_set_real_add_holder (GdaSet *set, GdaHolder *holder)
 			set->priv->holders_array = NULL;
 		}
 		g_object_ref (holder);
-		if (set->priv->validate_changes)
-			g_signal_connect (G_OBJECT (holder), "validate-change",
-					  G_CALLBACK (validate_change_holder_cb), set);
+		g_signal_connect (G_OBJECT (holder), "validate-change",
+				  G_CALLBACK (validate_change_holder_cb), set);
 		if (! set->priv->read_only) {
 			g_signal_connect (G_OBJECT (holder), "changed",
 					  G_CALLBACK (changed_holder_cb), set);
