@@ -1,23 +1,23 @@
-/* GDA Jdbc provider
- * Copyright (C) 2008 - 2010 The GNOME Foundation.
+/*
+ * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -962,8 +962,8 @@ static const gchar*
 gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnection *cnc, GType type)
 {
 	if (cnc) {
-		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
+		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, NULL);
 	}
 
 	TO_IMPLEMENT;
@@ -992,7 +992,6 @@ gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	    (type == G_TYPE_STRING) ||
 	    (type == GDA_TYPE_TIME) ||
 	    (type == GDA_TYPE_TIMESTAMP) ||
-	    (type == G_TYPE_INVALID) ||
 	    (type == G_TYPE_GTYPE))
 		return "string";
 
@@ -1008,6 +1007,10 @@ gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	if (type == G_TYPE_DATE)
 		return "date";
 
+	if ((type == GDA_TYPE_NULL) ||
+	    (type == G_TYPE_GTYPE))
+		return NULL;
+
 	return "text";
 }
 
@@ -1145,7 +1148,7 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
 		
 		GValue *jexec_res;
 		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__declareParamTypes,
-						     pstmt_obj, NULL, NULL, error, (jlong) cnc, jtypes);
+						     pstmt_obj, NULL, NULL, error, (jlong)GPOINTER_TO_INT(cnc), jtypes);
 		(*jenv)->DeleteLocalRef (jenv, jtypes);
 		g_free (ctypes);
 		
@@ -1317,7 +1320,23 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 			}
 		}
 		if (!h) {
-			if (! allow_noparam) {
+			if (allow_noparam) {
+                                /* bind param to NULL */
+				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
+				if (!jexec_res) {
+					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+					if (lerror)
+						gda_connection_event_set_description (event,
+						lerror->message ? lerror->message : _("No detail"));
+					g_propagate_error (error, lerror);
+					break;
+				}
+				gda_value_free (jexec_res);
+                                empty_rs = TRUE;
+                                continue;
+			}
+			else {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1326,8 +1345,11 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-			}
-			else {
+                        }
+
+		}
+		if (!gda_holder_is_valid (h)) {
+			if (allow_noparam) {
                                 /* bind param to NULL */
 				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
 								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
@@ -1342,11 +1364,8 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 				gda_value_free (jexec_res);
                                 empty_rs = TRUE;
                                 continue;
-                        }
-
-		}
-		if (!gda_holder_is_valid (h)) {
-			if (! allow_noparam) {
+			}
+			else {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1355,22 +1374,6 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-			}
-			else {
-                                /* bind param to NULL */
-				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
-				if (!jexec_res) {
-					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-					if (lerror)
-						gda_connection_event_set_description (event,
-						lerror->message ? lerror->message : _("No detail"));
-					g_propagate_error (error, lerror);
-					break;
-				}
-				gda_value_free (jexec_res);
-                                empty_rs = TRUE;
-                                continue;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1406,19 +1409,63 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 
 		/* actual binding using the C API, for parameter at position @i */
 		const GValue *value = gda_holder_get_value (h);
-		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-						     ps->pstmt_obj, NULL, NULL, &lerror, i, 
-						     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
-		if (!jexec_res) {
-			event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-			if (lerror)
-				gda_connection_event_set_description (event,
-								      lerror->message ? lerror->message : _("No detail"));
-
-			g_propagate_error (error, lerror);
-			break;
+		if (!value || gda_value_is_null (value)) {
+			GdaStatement *rstmt;
+			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
+				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+								     ps->pstmt_obj, NULL, NULL, &lerror, i, 
+								     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
+				if (!jexec_res) {
+					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+					if (lerror)
+						gda_connection_event_set_description (event,
+										      lerror->message ? lerror->message : _("No detail"));
+					
+					g_propagate_error (error, lerror);
+					break;
+				}
+				gda_value_free (jexec_res);
+			}
+			else if (!rstmt)
+				return NULL;
+			else {
+				GObject *obj;
+				g_object_unref (ps);
+				_gda_jdbc_release_jenv (jni_detach);
+				obj = gda_jdbc_provider_statement_execute (provider, cnc,
+									   rstmt, params,
+									   model_usage,
+									   col_types,
+									   last_inserted_row,
+									   task_id, async_cb,
+									   cb_data, error);
+				g_object_unref (rstmt);
+				if (GDA_IS_DATA_SELECT (obj)) {
+					GdaPStmt *pstmt;
+					g_object_get (obj, "prepared-stmt", &pstmt, NULL);
+					if (pstmt) {
+						gda_pstmt_set_gda_statement (pstmt, stmt);
+						g_object_unref (pstmt);
+					}
+				}
+				return obj;
+			}
+		}
+		else {
+			jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+							     ps->pstmt_obj, NULL, NULL, &lerror, i, 
+							     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
+			if (!jexec_res) {
+				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+				if (lerror)
+					gda_connection_event_set_description (event,
+									      lerror->message ? lerror->message : _("No detail"));
+				
+				g_propagate_error (error, lerror);
+				break;
+			}
+			gda_value_free (jexec_res);
 		}
-		gda_value_free (jexec_res);
 	}
 		
 	if (event) {
