@@ -1,27 +1,29 @@
 /*
- * Copyright (C) 2009 - 2011 The GNOME Foundation.
+ * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
+ * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ * Copyright (C) 2002 Tim Coleman <tim@timcoleman.com>
+ * Copyright (C) 2003 Christian Neumair <cneumair@src.gnome.org>
+ * Copyright (C) 2003 Steve Fosdick <fozzy@src.gnome.org>
+ * Copyright (C) 2004 Julio M. Merino Vidal <jmmv@menta.net>
+ * Copyright (C) 2005 Magnus Bergman <magnus.bergman@observer.net>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  *
- * AUTHORS:
- *      Rodrigo Moya <rodrigo@gnome-db.org>
- *      Tim Coleman <tim@timcoleman.com>
- *      Vivien Malerba <malerba@gnome-db.org>
- *      Bas Driessen <bas.driessen@xobas.com>
- *      Andrea Zagli <azagli@libero.it>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #undef GDA_DISABLE_DEPRECATED
@@ -1185,8 +1187,8 @@ static const gchar*
 gda_oracle_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnection *cnc, GType type)
 {
 	if (cnc) {
-		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
+		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, NULL);
 	}
 
 	TO_IMPLEMENT;
@@ -1215,7 +1217,6 @@ gda_oracle_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConne
 	    (type == G_TYPE_STRING) ||
 	    (type == GDA_TYPE_TIME) ||
 	    (type == GDA_TYPE_TIMESTAMP) ||
-	    (type == G_TYPE_INVALID) ||
 	    (type == G_TYPE_GTYPE))
 		return "VARCHAR2";
 
@@ -1231,6 +1232,10 @@ gda_oracle_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConne
 	if (type == G_TYPE_DATE)
 		return "DATE";
 
+	if ((type == GDA_TYPE_NULL) ||
+	    (type == G_TYPE_GTYPE))
+		return NULL;
+
 	return "VARCHAR2";
 }
 
@@ -1825,7 +1830,14 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 			}
 		}
 		if (!h) {
-			if (! allow_noparam) {
+			if (allow_noparam) {
+                                /* bind param to NULL */
+				/* Hint: Indicator Variables, see p. 118 */
+				ora_value = g_new0 (GdaOracleValue, 1);
+				ora_value->indicator = -1;
+                                empty_rs = TRUE;
+			}
+			else {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1834,18 +1846,16 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-			}
-			else {
+                        }
+		}
+		else if (!gda_holder_is_valid (h)) {
+			if (allow_noparam) {
                                 /* bind param to NULL */
-				/* Hint: Indicator Variables, see p. 118 */
 				ora_value = g_new0 (GdaOracleValue, 1);
 				ora_value->indicator = -1;
                                 empty_rs = TRUE;
-                        }
-
-		}
-		else if (!gda_holder_is_valid (h)) {
-			if (! allow_noparam) {
+			}
+			else {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1854,12 +1864,6 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-			}
-			else {
-                                /* bind param to NULL */
-				ora_value = g_new0 (GdaOracleValue, 1);
-				ora_value->indicator = -1;
-                                empty_rs = TRUE;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1893,33 +1897,86 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 		}
 
 		/* actual binding using the C API, for parameter at position @i */
-		if (!ora_value) {
-			const GValue *value = gda_holder_get_value (h);
+		const GValue *value = gda_holder_get_value (h);
+		if (!ora_value)
 			ora_value = _gda_value_to_oracle_value (value);
-		}
-		OCIBind *bindpp = (OCIBind *) 0;
-		int result;
-		result = OCIBindByName ((dvoid *) ps->hstmt,
-					(OCIBind **) &bindpp,
-					(OCIError *) cdata->herr,
-					/* param name */
-					(text *) (real_pname ? real_pname : pname),
-					(sb4) strlen (real_pname ? real_pname : pname),
-					/* bound value */
-					(dvoid *) ora_value->value,
-					(sb4) ora_value->defined_size,
-					(ub2) ora_value->sql_type,
-					(dvoid *) &ora_value->indicator,
-					(ub2 *) 0,
-					(ub2) 0,
-					(ub4) 0,
-					(ub4 *) 0,
-					(ub4) OCI_DEFAULT);
 
-		oravalues_list = g_slist_prepend (oravalues_list, ora_value);
-		if ((event = gda_oracle_check_result (result, cnc, cdata, OCI_HTYPE_ERROR,
-						      _("Could not bind the Oracle statement parameter"))))
-			break;
+		if (!value || gda_value_is_null (value)) {
+			GdaStatement *rstmt;
+			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
+				OCIBind *bindpp = (OCIBind *) 0;
+				int result;
+				result = OCIBindByName ((dvoid *) ps->hstmt,
+							(OCIBind **) &bindpp,
+							(OCIError *) cdata->herr,
+							/* param name */
+							(text *) (real_pname ? real_pname : pname),
+							(sb4) strlen (real_pname ? real_pname : pname),
+							/* bound value */
+							(dvoid *) ora_value->value,
+							(sb4) ora_value->defined_size,
+							(ub2) ora_value->sql_type,
+							(dvoid *) &ora_value->indicator,
+							(ub2 *) 0,
+							(ub2) 0,
+							(ub4) 0,
+							(ub4 *) 0,
+							(ub4) OCI_DEFAULT);
+				
+				oravalues_list = g_slist_prepend (oravalues_list, ora_value);
+				if ((event = gda_oracle_check_result (result, cnc, cdata, OCI_HTYPE_ERROR,
+								      _("Could not bind the Oracle statement parameter"))))
+					break;
+			}
+			else if (!rstmt)
+				return NULL;
+			else {
+				GObject *obj;
+				g_object_unref (ps);
+				obj = gda_oracle_provider_statement_execute (provider, cnc,
+									     rstmt, params,
+									     model_usage,
+									     col_types,
+									     last_inserted_row,
+									     task_id, async_cb,
+									     cb_data, error);
+				g_object_unref (rstmt);
+				if (GDA_IS_DATA_SELECT (obj)) {
+					GdaPStmt *pstmt;
+					g_object_get (obj, "prepared-stmt", &pstmt, NULL);
+					if (pstmt) {
+						gda_pstmt_set_gda_statement (pstmt, stmt);
+						g_object_unref (pstmt);
+					}
+				}
+				return obj;
+			}
+		}
+		else {
+			OCIBind *bindpp = (OCIBind *) 0;
+			int result;
+			result = OCIBindByName ((dvoid *) ps->hstmt,
+						(OCIBind **) &bindpp,
+						(OCIError *) cdata->herr,
+						/* param name */
+						(text *) (real_pname ? real_pname : pname),
+						(sb4) strlen (real_pname ? real_pname : pname),
+						/* bound value */
+						(dvoid *) ora_value->value,
+						(sb4) ora_value->defined_size,
+						(ub2) ora_value->sql_type,
+						(dvoid *) &ora_value->indicator,
+						(ub2 *) 0,
+						(ub2) 0,
+						(ub4) 0,
+						(ub4 *) 0,
+						(ub4) OCI_DEFAULT);
+
+			oravalues_list = g_slist_prepend (oravalues_list, ora_value);
+			if ((event = gda_oracle_check_result (result, cnc, cdata, OCI_HTYPE_ERROR,
+							      _("Could not bind the Oracle statement parameter"))))
+				break;
+		}
 	}
 		
 	if (event) {
