@@ -280,8 +280,11 @@ finish_prep_stmt_init (PostgresConnectionData *cdata, GdaPostgresPStmt *ps, PGre
 									 gda_column_new ());
 		_GDA_PSTMT (ps)->tmpl_columns = g_slist_reverse (_GDA_PSTMT (ps)->tmpl_columns);
 
-		/* create prepared statement's types */
-		_GDA_PSTMT (ps)->types = g_new0 (GType, _GDA_PSTMT (ps)->ncols); /* all types are initialized to GDA_TYPE_NULL */
+		/* create prepared statement's types, all types are initialized to GDA_TYPE_NULL */
+		_GDA_PSTMT (ps)->types = g_new (GType, _GDA_PSTMT (ps)->ncols);
+		for (i = 0; i < _GDA_PSTMT (ps)->ncols; i++)
+			_GDA_PSTMT (ps)->types [i] = GDA_TYPE_NULL;
+
 		if (col_types) {
 			for (i = 0; ; i++) {
 				if (col_types [i] > 0) {
@@ -308,7 +311,7 @@ finish_prep_stmt_init (PostgresConnectionData *cdata, GdaPostgresPStmt *ps, PGre
 			column = GDA_COLUMN (list->data);
 			postgres_type = PQftype (pg_res, i);
 			gtype = _GDA_PSTMT (ps)->types [i];
-			if (gtype == 0) {
+			if (gtype == GDA_TYPE_NULL) {
 				gtype = _gda_postgres_type_oid_to_gda (cdata->cnc, cdata->reuseable, postgres_type);
 				_GDA_PSTMT (ps)->types [i] = gtype;
 			}
@@ -437,10 +440,13 @@ gda_postgres_recordset_fetch_random (GdaDataSelect *model, GdaRow **prow, gint r
 {
 	GdaPostgresRecordset *imodel = (GdaPostgresRecordset *) model;
 
+	if (*prow)
+		return TRUE;
+
 	if (!imodel->priv->pg_res) {
 		g_set_error (error, GDA_SERVER_PROVIDER_ERROR, GDA_SERVER_PROVIDER_INTERNAL_ERROR,
 			     "%s", _("Internal error"));
-		return TRUE;
+		return FALSE;
 	}
 
 	*prow = new_row_from_pg_res (imodel, rownum, error);
@@ -483,19 +489,23 @@ gda_postgres_recordset_store_all (GdaDataSelect *model, GError **error)
  * Create a new filled #GdaRow object for the next cursor row, and put it into *prow.
  *
  * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
+ * never keeps a reference to it). Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean
 gda_postgres_recordset_fetch_next (GdaDataSelect *model, GdaRow **prow, gint rownum, GError **error)
 {
 	GdaPostgresRecordset *imodel = (GdaPostgresRecordset*) model;
 
+	if (*prow)
+		return TRUE;
+
 	if (row_is_in_current_pg_res (imodel, rownum)) {
 		if (imodel->priv->tmp_row)
 			set_prow_with_pg_res (imodel, imodel->priv->tmp_row, rownum - imodel->priv->pg_res_inf, error);
 		else
 			imodel->priv->tmp_row = new_row_from_pg_res (imodel, rownum - imodel->priv->pg_res_inf, error);
 		*prow = imodel->priv->tmp_row;
+		return TRUE;
 	}
 	else {
 		gboolean fetch_error = FALSE;
@@ -505,28 +515,34 @@ gda_postgres_recordset_fetch_next (GdaDataSelect *model, GdaRow **prow, gint row
 			else
 				imodel->priv->tmp_row = new_row_from_pg_res (imodel, rownum - imodel->priv->pg_res_inf, error);
 			*prow = imodel->priv->tmp_row;
+			return TRUE;
 		}
+		else
+			return !fetch_error;
 	}
-	return TRUE;
 }
 
 /*
  * Create a new filled #GdaRow object for the previous cursor row, and put it into *prow.
  *
  * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
+ * never keeps a reference to it). Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean
 gda_postgres_recordset_fetch_prev (GdaDataSelect *model, GdaRow **prow, gint rownum, GError **error)
 {
 	GdaPostgresRecordset *imodel = (GdaPostgresRecordset*) model;
 
+	if (*prow)
+		return TRUE;
+
 	if (row_is_in_current_pg_res (imodel, rownum)) {
 		if (imodel->priv->tmp_row)
 			set_prow_with_pg_res (imodel, imodel->priv->tmp_row, rownum - imodel->priv->pg_res_inf, error);
 		else
 			imodel->priv->tmp_row = new_row_from_pg_res (imodel, rownum - imodel->priv->pg_res_inf, error);
 		*prow = imodel->priv->tmp_row;
+		return TRUE;
 	}
 	else {
 		gboolean fetch_error = FALSE;
@@ -536,22 +552,27 @@ gda_postgres_recordset_fetch_prev (GdaDataSelect *model, GdaRow **prow, gint row
 			else
 				imodel->priv->tmp_row = new_row_from_pg_res (imodel, rownum - imodel->priv->pg_res_inf, error);
 			*prow = imodel->priv->tmp_row;
+			return TRUE;
 		}
+		else
+			return !fetch_error;
 	}
-	return TRUE;
 }
 
 /*
  * Create a new filled #GdaRow object for the cursor row at position @rownum, and put it into *prow.
  *
  * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
+ * never keeps a reference to it). Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean
 gda_postgres_recordset_fetch_at (GdaDataSelect *model, GdaRow **prow, gint rownum, GError **error)
 {
 	GdaPostgresRecordset *imodel = (GdaPostgresRecordset*) model;
 
+	if (*prow)
+		return TRUE;
+
 	if (imodel->priv->tmp_row) {
 		g_object_unref (imodel->priv->tmp_row);
 		imodel->priv->tmp_row = NULL;
@@ -560,15 +581,18 @@ gda_postgres_recordset_fetch_at (GdaDataSelect *model, GdaRow **prow, gint rownu
 	if (row_is_in_current_pg_res (imodel, rownum)) {
 		*prow = new_row_from_pg_res (imodel, rownum - imodel->priv->pg_res_inf, error);
 		imodel->priv->tmp_row = *prow;
+		return TRUE;
 	}
 	else {
 		gboolean fetch_error = FALSE;
 		if (fetch_row_number_chunk (imodel, rownum, &fetch_error, error)) {
 			*prow = new_row_from_pg_res (imodel, rownum - imodel->priv->pg_res_inf, error);
 			imodel->priv->tmp_row = *prow;
+			return TRUE;
 		}
+		else
+			return !fetch_error;
 	}
-	return TRUE;
 }
 
 
@@ -676,73 +700,14 @@ set_value (GdaConnection *cnc, GdaRow *row, GValue *value, GType type, const gch
 		 */
 		guchar *unescaped;
                 size_t pqlength = 0;
-		PostgresConnectionData *cdata;
-		gboolean valueset = FALSE;
 
-		cdata = (PostgresConnectionData*) gda_connection_internal_get_provider_data (cnc);
-		if (cdata) {
-			if ((thevalue[0] == '\\') && (thevalue[1] == 'x')) {
-				guint len;
-				len = strlen (thevalue + 2);
-				if (!(len % 2)) {
-					guint i;
-					const gchar *ptr;
-					pqlength = len / 2;
-					unescaped = g_new (guchar, pqlength);
-					for (i = 0, ptr = thevalue + 2; *ptr; i++, ptr += 2) {
-						gchar c;
-						c = ptr[0];
-						if ((c >= 'a') && (c <= 'z'))
-							unescaped [i] = c - 'a' + 10;
-						else if ((c >= 'A') && (c <= 'Z'))
-							unescaped [i] = c - 'A' + 10;
-						else if ((c >= '0') && (c <= '9'))
-							unescaped [i] = c - '0';
-						else
-							break;
-						unescaped [i] <<= 4;
-
-						c = ptr[1];
-						if ((c >= 'a') && (c <= 'z'))
-							unescaped [i] += c - 'a' + 10;
-						else if ((c >= 'A') && (c <= 'Z'))
-							unescaped [i] += c - 'A' + 10;
-						else if ((c >= '0') && (c <= '9'))
-							unescaped [i] += c - '0';
-						else
-							break;
-					}
-					if (! *ptr) {
-						GdaBinary *bin;
-						bin = g_new (GdaBinary, 1);
-						bin->data = unescaped;
-						bin->binary_length = pqlength;
-						gda_value_take_binary (value, bin);
-						valueset = TRUE;
-					}
-				}
-			}
-			else {
-				unescaped = PQunescapeBytea ((guchar*) thevalue, &pqlength);
-				if (unescaped) {
-					GdaBinary bin;
-					bin.data = unescaped;
-					bin.binary_length = pqlength;
-					gda_value_set_binary (value, &bin);
-					PQfreemem (unescaped);
-					valueset = TRUE;
-				}
-			}
-		}
-		if (!valueset) {
-			gchar *tmp;
-			tmp = g_strndup (thevalue, 20);
-			gda_row_invalidate_value (row, value);
-			g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-				     GDA_SERVER_PROVIDER_DATA_ERROR,
-				     _("Invalid binary string representation '%s ...'"), 
-				     tmp);
-			g_free (tmp);
+		unescaped = PQunescapeBytea ((guchar*)thevalue, &pqlength);
+		if (unescaped != NULL) {
+			GdaBinary bin;
+			bin.data = unescaped;
+			bin.binary_length = pqlength;
+			gda_value_set_binary (value, &bin);
+			PQfreemem (unescaped);
 		}
 	}
 	else if (type == GDA_TYPE_BLOB) {
