@@ -1,11 +1,12 @@
-/* browser-canvas.c
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
  *
- * Copyright (C) 2007 - 2010 Vivien Malerba
- *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -25,6 +25,7 @@
 #include "browser-canvas-item.h"
 #include "browser-canvas-print.h"
 #include <libgda/libgda.h>
+#include <libgda-ui/libgda-ui.h>
 
 #define DEFAULT_SCALE .8
 #ifdef HAVE_GRAPHVIZ
@@ -310,8 +311,10 @@ motion_notify_event_cb (BrowserCanvas *canvas, GdkEvent *event, G_GNUC_UNUSED Go
 	return done;
 }
 
+#ifdef HAVE_GRAPHVIZ
 static void popup_layout_default_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
 static void popup_layout_radial_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
+#endif
 static void popup_zoom_in_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
 static void popup_zoom_out_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
 static void popup_zoom_fit_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
@@ -435,6 +438,7 @@ canvas_event_cb (BrowserCanvas *canvas, GdkEvent *event, GooCanvas *gcanvas)
 	return done;	
 }
 
+#ifdef HAVE_GRAPHVIZ
 static void
 popup_layout_default_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 {
@@ -446,6 +450,7 @@ popup_layout_radial_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 {
 	browser_canvas_perform_auto_layout (canvas, TRUE, BROWSER_CANVAS_LAYOUT_RADIAL);
 }
+#endif
 
 static void
 popup_zoom_in_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
@@ -483,6 +488,8 @@ popup_export_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 					   NULL);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlg),
+					     gdaui_get_default_path ());
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("PNG Image"));
 	gtk_file_filter_add_mime_type (filter, "image/png");
@@ -499,6 +506,7 @@ popup_export_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 		gchar *lcfilename;
 		cairo_surface_t *surface = NULL;
 
+		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg)));
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dlg));
 		if (filename) {
 			GooCanvasBounds bounds;
