@@ -85,7 +85,7 @@ schema_browser_perspective_get_type (void)
 		
 		g_static_mutex_lock (&registering);
 		if (type == 0) {
-			type = g_type_register_static (GTK_TYPE_VBOX, "SchemaBrowserPerspective", &info, 0);
+			type = g_type_register_static (GTK_TYPE_BOX, "SchemaBrowserPerspective", &info, 0);
 			g_type_add_interface_static (type, BROWSER_PERSPECTIVE_TYPE, &perspective_info);
 		}
 		g_static_mutex_unlock (&registering);
@@ -118,6 +118,8 @@ schema_browser_perspective_init (SchemaBrowserPerspective *perspective)
 {
 	perspective->priv = g_new0 (SchemaBrowserPerspectivePrivate, 1);
 	perspective->priv->favorites_shown = TRUE;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (perspective), GTK_ORIENTATION_VERTICAL);
 }
 
 static void fav_selection_changed_cb (GtkWidget *widget, gint fav_id, BrowserFavoritesType fav_type,
@@ -145,7 +147,7 @@ schema_browser_perspective_new (BrowserWindow *bwin)
 
 	/* contents */
 	GtkWidget *paned, *wid, *nb;
-	paned = gtk_hpaned_new ();
+	paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	if (fav_supported) {
 		wid = favorite_selector_new (bcnc);
 		g_signal_connect (wid, "selection-changed",
